<?php
if (!class_exists('EmailsTpl_Users'))
{
	class EmailsTpl_Users
	{
		/**
		 * Return the email of the admin
		 * 
		 * Return The Administrator's E-mail address set in Administration → Settings → General. 
		 * This data is retrieved from the admin_email record in the wp_options table. 
		 *
		 * @static 
		 * @return string
		 * @access public
		 * 
		 */
		static function get_admin_email()
		{
			if (class_exists('GpcKits_Users'))
				return GpcKits_Users::get_admin_email();
			else
				return '';
		}
		
		/**
		 * Return all users 
		 *
		 * @static 
		 * @return array
		 * @access public
		 * 
		 */
		static function get_users() 
		{
			if (class_exists('GpcKits_Users'))
				return GpcKits_Users::get_users();
			else
				return array();
		}
		
		/**
		 * Check if user is authenticated, if not, redirect to User Login page 
		 *
		 * @static 
		 * @return void
		 * @access public
		 * 
		 */
		static function user_must_be_authenticated() 
		{
			if (class_exists('GpcKits_Users'))
				return GpcKits_Users::user_must_be_authenticated();
		}
		
		/**
		 * Check if an administrator is authenticated, if not, redirect to User Login page 
		 *
		 * @static 
		 * @return void
		 * @access public
		 * 
		 */
		static function an_admin_must_be_authenticated() 
		{
			if (class_exists('GpcKits_Users'))
				return GpcKits_Users::an_admin_must_be_authenticated();
		}
		
		/**
		 * Get user Type
		 * 
		 * Can return the following values: empty if no user is logged in, 
		 * "admin" if the administrator is logged in, 
		 * "registered" if there are a non-admin user logged in
		 *
		 * @static 
		 * @return string
		 * @access public
		 * 
		 */
		static function get_user_type() 
		{
			if (self::is_user_authenticate()) {
				if (self::is_administrator_authenticate())
					$user_type = 'admin';
				else 
					$user_type = 'registered';
			}
			else { 
				$user_type = '';
			}
			
			return $user_type;
		}
		
		/**
		 * Check if are any user authenticated
		 *
		 * @static 
		 * @return boolean
		 * @access public
		 * 
		 */
		static function is_user_authenticate() 
		{
			if (class_exists('GpcKits_Users'))
				return GpcKits_Users::is_user_authenticate();
			else
				return FALSE;
		}
		
		/**
		 * Return current user ID
		 *
		 * @static 
		 * @return int
		 * @access public
		 * 
		 */
		static function get_current_user_id() 
		{
			if (class_exists('GpcKits_Users'))
				return GpcKits_Users::get_current_user_id();
			else
				return 0;
		}
		
		/**
		 * Get user login
		 *
		 * @static 
		 * @param int $user_id when isn't received the informations is about the authenticated user
		 * @return string
		 * @access public
		 */
		static function get_user_login($user_id = '') 
		{
			if (class_exists('GpcKits_Users'))
				return GpcKits_Users::get_user_login($user_id);
			else
				return '';
		}
		
		/**
		 * Checks if the administrator is logued
		 *
		 * @static 
		 * @return boolean return TRUE if is administrator, else return FALSE
		 * @access public
		 */
		static function is_administrator_authenticate() 
		{
			if (class_exists('GpcKits_Users'))
				return GpcKits_Users::is_administrator_authenticate();
			else
				return FALSE;
		}
		
		/**
		 * Get user name
		 *
		 * @static 
		 * @param int $user_id
		 * @return string
		 * @access public
		 */
		static function get_user_name($user_id='') 
		{
			if (class_exists('GpcKits_Users'))
				return GpcKits_Users::get_user_name($user_id);
			else
				return '';
		}
		
		/**
		 * Get user email
		 *
		 * @static 
		 * @param int $user_id
		 * @return string
		 * @access public 
		 */
		static function get_user_email($user_id='') 
		{
			if (class_exists('GpcKits_Users'))
				return GpcKits_Users::get_user_email($user_id);
			else
				return '';
		}
		
		/**
		 * Checks if user is the "admin" user
		 *
		 * @static 
		 * @param int $user_id
		 * @return boolean return TRUE if is administrator, else return FALSE
		 * @access public 
		 */
		static function is_admin_user($user_id='') 
		{
			if (class_exists('GpcKits_Users'))
				return GpcKits_Users::is_admin_user($user_id);
			else
				return FALSE;
		}
		
		/**
		 * Get User ID  
		 * 
		 * @static 
		 * @param string $user_login
		 * @return int
		 * @access public
		 */
		static function get_user_id($user_login) 
		{
			if (class_exists('GpcKits_Users'))
				return GpcKits_Users::get_user_id($user_login);
			else
				return 0;
		}		
	}
}
?>