<?php
/*
Plugin Name: Emails Templates
Description: Allows the edition and use of email templates.
Version: 0.1
Author: gpc
*/

/**
 * Version of WordPress
 * @since
 * @global    string    $wp_version
 *
 */

global $wp_version;

$exit_msg = __('This plugin require WordPress 2.8.4 or newer','emails-tpl').'. <a href="http://codex.wordpress.org/Upgrading_WordPress">'.__('Please update','emails-tpl').'</a>';
  
if (version_compare($wp_version, "2.8.4", "<")) {
	exit($exit_msg);
}

// Avoid name collisions.
if (!class_exists('EmailsTpl'))
{
	class EmailsTpl
    {
       /**
	    * The url to the plugin
	    *
	    * @static 
	    * @var string
	    */
        static $plugin_url;
         
       /**
	    * The path to the plugin
	    *
	    * @static 
	    * @var string
	    */
        static $plugin_dir;
         
       /**
	    * The descriptive name for plugin
	    *
	    * @var string
	    */
        static $plugin_desc_name;
        
       /**
	    * The prefix for tables in the DB
	    *
	    * @var string
	    */
        static $db_prefix = 'emails_tpl_';
        
        /**
         * Executes all initialization code for the plugin.
         * 
         * @return void
         * @access public
		 */
        function EmailsTpl(){
        	// Define static values
        	self::$plugin_url = trailingslashit( WP_PLUGIN_URL.'/'. dirname( plugin_basename(__FILE__) ));
        	self::$plugin_dir = pathinfo(__FILE__,PATHINFO_DIRNAME);
        	self::$plugin_desc_name = __('Emails Templates','emails-tpl');
        	
        	// Include all classes
        	include( self::$plugin_dir . '/includes/all_classes.php');
        	
        	// Add options Page
           	add_action('admin_menu', array(&$this, 'admin_menu'));
           	
           	// Adding headers
			add_action("admin_head", array(&$this, 'add_admin_header'));
			add_action("wp_head", array(&$this, 'add_wp_head'));
			
			// Translations for plugin
			$this->handle_load_domain();
			
        	// Check for required plugin, if isn't active show message
	        $plugins = get_option('active_plugins');
			$required_plugin = 'gpc-kits/gpc-kits.php';
			if (!in_array($required_plugin, $plugins) && !isset($_GET['action'])) { //  && !isset($_GET['action']): Is to avoid problem when active/deactive plugins
				$msg_error = sprintf(__('The %s plugin require the activation of GPC Kits plugin. See readme.txt for more information.','b2b-plugin4'), self::$plugin_desc_name);
				$_SESSION['msg_error'][] = $msg_error;
			}
        }
       
        /**
		 * Handles the main menu options page for General Settings
		 * 
		 * @return void
		 * @access public
		 */
        function handle_menu_email_templates()
        {
        	if (isset($_GET['id'])) // Editing Template
           		include('includes/admin/email_tpl_form.php');
           	else 
           		include('includes/admin/email_tpl_list.php');
        }
        
        
    	/** 
		 * Hooks the add the main menu
		 * 
		 * @return void
		 * @access public
		 */
        function admin_menu()
        {
            add_theme_page(__('Email Templates','emails-tpl'), __('Email Templates','emails-tpl'), 8, 'email_templates', array(&$this, 'handle_menu_email_templates'));
        }
        
	    /**
		 * Handles the instalation code of the plugin. Executed only one time
		 * 
		 * @global $wpdb used to access to WordPress Object that manage DB
		 * @return void
		 * @access public
		 */
        function install()
        {
        	// Creating tables
			include('db/tables.php');
        }
        
        /**
		 * Handles the uninstall code of the plugin. Executed only one time
		 * 
		 * @return void
		 * @access public
		 */
        function uninstall()
        {
        	// For now nothing in unistall, because we don't want user lose the data. 
        }
        
    	/**
         * Add html code inside the tag <head> of the admin pages.
         * 
         * @return void
         * @access public
		 */
        function add_admin_header() {
        }
		
    	/**
         * Add html code inside the tag <head> of the user pages.
         * 
         * @return void
         * @access public
		 */
        function add_wp_head() {
        }
		
     	/**
         * Handles the translation of plugin
         * 
         * @return void
         * @access public
		 */
        function handle_load_domain()
		{
			$plugin_domain = 'emails-tpl';
			
			// TODO: define how client want get this value
			$locale = 'de_DE';
				
			if ($locale!='')
			{
				// locate translation file
				$mofile = WP_PLUGIN_DIR.'/'.plugin_basename(dirname
				(__FILE__)).'/lang/' . $plugin_domain . '-' .
				$locale . '.mo';
				// load translation
				load_textdomain($plugin_domain, $mofile);
			}
		}		
	}
}

// create new instance of the class
$EmailsTpl = new EmailsTpl();
if (isset($EmailsTpl)) {
    // register the activation function by passing the reference to our instance
    register_activation_hook(__FILE__, array(&$EmailsTpl, 'install'));
    register_deactivation_hook(__FILE__, array(&$EmailsTpl, 'uninstall'));
}

?>
